@@ -4,7 +4,8 @@
 	   character-code
 	   utf16-code
 	   negative-fixnum
-	   n-byte))
+	   n-byte
+	   simple-characters))
 (in-package :igo.type)
   
 (deftype array-index ()    `(integer 0 ,array-total-size-limit))
@@ -12,4 +13,5 @@
 (deftype utf16-code ()     `(integer 0 #xFFFF))
 (deftype negative-fixnum ()`(integer ,most-negative-fixnum -1))
 (deftype n-byte (byte-size signed?) 
-  `(,(if signed? 'signed-byte 'unsigned-byte) ,(* byte-size 8)))
\ No newline at end of file
+  `(,(if signed? 'signed-byte 'unsigned-byte) ,(* byte-size 8)))
+(deftype simple-characters () '(simple-array character (*)))
\ No newline at end of file
